==> digikam-3.0.0-beta1.tar.bz2: digikam-3.0.0-beta1/extra/kipi-plugins/wallpaper/kipiplugin_wallpaper.desktop.cmake <==
[Desktop Entry]
Name=WallPaper
Name[ar]=الخلفية
Name[ast]=Fondu d'escritoriu
Name[be]=Шпалеры
Name[bg]=Тапет
Name[bs]=Pozadinska slika
Name[ca]=Fons d'escriptori
Name[ca@valencia]=Fons d'escriptori
Name[cs]=Tapeta
Name[da]=WallPaper
Name[de]=Hintergrundbild
Name[el]=Ταπετσαρία
Name[en_GB]=WallPaper
Name[es]=Fondo de escritorio
Name[et]=Taustapilt
Name[eu]=Horma-papera
Name[fi]=Taustakuva
Name[fr]=Fond d'écran
Name[ga]=WallPaper
Name[gl]=Fondo de escritorio
Name[he]=רקע
Name[hne]=वालपेपर
Name[hu]=Háttérkép
Name[is]=Veggfóður
Name[it]=Sfondo
Name[ja]=WallPaper
Name[km]=ផ្ទាំង​រូបភាព
Name[ko]=WallPaper
Name[lv]=Ekrāntapete
Name[nb]=Bakgrunnsbilde
Name[nds]=Achtergrundbild
Name[nl]=Bureaubladachtergrond
Name[pa]=ਵਾਲਪੇਪਰ
Name[pl]=Tapeta
Name[pt]=Papel de Parede
Name[pt_BR]=Papel de parede
Name[ro]=Fundal de ecran
Name[ru]=Обои
Name[sk]=Pozadie
Name[sl]=WallPaper
Name[sq]=WallPaper
Name[sv]=Skrivbordsunderlägg
Name[th]=ภาพพื้นหลัง
Name[tr]=Duvar Kağıdı
Name[uk]=WallPaper
Name[x-test]=xxWallPaperxx
Name[zh_CN]=壁纸
Name[zh_TW]=桌布
Comment=A tool to set image as background on your desktop
Comment[ast]=Una ferramienta pa poner una imaxe como fondu de pantalla nel escritoriu
Comment[bg]=Инструмент за поставяне на изображения като тапет на екрана
Comment[bs]=Alat za postavljanje slike na vašu radnu površinu
Comment[ca]=Una eina per a definir una imatge com a fons de l'escriptori
Comment[ca@valencia]=Una eina per a definir una imatge com a fons de l'escriptori
Comment[cs]=Nástroj pro odeslání obrázku jako pozadí Vaší plochy
Comment[da]=Et værktøj til at sætte et billede som baggrund på dit skrivebord
Comment[de]=Ein Werkzeug, um ein Bild als Hintergrundbild Ihrer Arbeitsfläche zu setzen.
Comment[el]=Εργαλείο ορισμού εικόνας ως φόντου της επιφάνειας εργασίας σας
Comment[en_GB]=A tool to set image as background on your desktop
Comment[es]=Una herramienta para configurar el fondo del escritorio
Comment[et]=Tööriist pildi määramiseks töölaua taustapildiks
Comment[eu]=Irudia mahaigaineko azteko plano gisa ezartzeko tresna
Comment[fi]=Taustakuvan vaihto
Comment[fr]=Outil pour mettre une image d'arrière plan sur le bureau
Comment[ga]=Uirlis a shocraíonn íomhá mar chúlbhrat do dheisce
Comment[gl]=Unha ferramenta para pór unha imaxe como fondo do escritorio
Comment[he]=כלי לקביעת התמונה כרקע של שולחן העבודה
Comment[hne]=फोटू ल आप मन के डेस्कटाप मं पिछोत अंगना फोटू रूप मं सेट करे के एक औजार
Comment[hu]=Egy eszköz kép beállításához az asztal háttérképeként
Comment[is]=Verkfæri til að setja mynd sem bakgrunn á skjáborðið þitt
Comment[it]=Uno strumento per impostare l'immagine come sfondo del desktop
Comment[ja]=画像をデスクトップの壁紙に設定するツール
Comment[km]=ឧបករណ៍​ត្រូវ​កំណត់​រូបភាព​ជា​ផ្ទៃ​ខាង​ក្រោយ​នៅ​លើ​ផ្ទៃតុ​របស់​អ្នក
Comment[lv]=Rīks attēla iestatīšanai par darbvirsmas ekrāntapeti
Comment[nb]=Et verktøy for å bruke et bilde som bakgrunn på skrivebordet
Comment[nds]=En Warktüüch, mit dat Du Biller as Achtergrund för Dien Schriefdisch bruken kannst.
Comment[nl]=Een hulpmiddel voor het instellen van een afbeelding als achtergrond van uw bureaublad
Comment[pa]=ਤੁਹਾਡੇ ਡੈਸਕਟਾਪ ਦੀ ਬੈਕਗਰਾਊਂਡ ਉੱਤੇ ਚਿੱਤਰ ਲਾਉਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do ustawiania obrazu jako tła twojego pulpitu
Comment[pt]=Uma ferramenta para configurar uma imagem como fundo do seu ecrã
Comment[pt_BR]=Uma ferramenta para definir imagem como plano de fundo de sua área de trabalho
Comment[ro]=O unealtă pentru definirea unei imagini ca fundal de ecran
Comment[ru]=Инструмент для установки изображения в качестве обоев рабочего стола
Comment[sk]=Nástroj na nastavenie obrázku ako pozadie pracovnej plochy
Comment[sl]=Orodje s katerim lahko nastavite sliko kot ozadje vašega namizja
Comment[sq]=Një mjet për të vendosur imazhin si sfond për desktopin tuaj
Comment[sv]=Ett verktyg för att använda bilder som skrivbordsunderlägg
Comment[th]=เครื่องมือในการตั้งภาพเป็นภาพพื้นหลังบนพื้นที่ทำงานของคุณ
Comment[tr]=Resimi masaüstü arkaplanı olarak belirlemek için bir araç
Comment[uk]=Інструмент для встановлення зображення тла стільниці
Comment[x-test]=xxA tool to set image as background on your desktopxx
Comment[zh_CN]=一个设定图像作为您桌面背景的工具
Comment[zh_TW]=將影像設定為您的桌面背景的工具
Type=Service
Icon=image-jpeg
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_wallpaper
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-PluginCategories=Image

==> digikam-3.2.0-beta1.tar.bz2: digikam-3.2.0-beta1/extra/kipi-plugins/wallpaper/kipiplugin_wallpaper.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=WallPaper
Name=WallPaper
Name[ar]=الخلفية
Name[ast]=Fondu d'escritoriu
Name[be]=Шпалеры
Name[bg]=Тапет
Name[bs]=Pozadinska slika
Name[ca]=Fons d'escriptori
Name[ca@valencia]=Fons d'escriptori
Name[cs]=Tapeta
Name[da]=WallPaper
Name[de]=Hintergrundbild
Name[el]=Ταπετσαρία
Name[en_GB]=WallPaper
Name[es]=Fondo de escritorio
Name[et]=Taustapilt
Name[eu]=Horma-papera
Name[fi]=Taustakuva
Name[fr]=Fond d'écran
Name[ga]=WallPaper
Name[gl]=Fondo de escritorio
Name[he]=רקע
Name[hne]=वालपेपर
Name[hu]=Háttérkép
Name[is]=Veggfóður
Name[it]=Sfondo
Name[ja]=WallPaper
Name[km]=ផ្ទាំង​រូបភាព
Name[ko]=WallPaper
Name[lv]=Ekrāntapete
Name[mr]=वॉलपेपर
Name[nb]=Bakgrunnsbilde
Name[nds]=Achtergrundbild
Name[nl]=Bureaubladachtergrond
Name[pa]=ਵਾਲਪੇਪਰ
Name[pl]=Tapeta
Name[pt]=Papel de Parede
Name[pt_BR]=Papel de parede
Name[ro]=Fundal de ecran
Name[ru]=Обои
Name[sk]=Pozadie
Name[sl]=WallPaper
Name[sq]=WallPaper
Name[sv]=Skrivbordsunderlägg
Name[th]=ภาพพื้นหลัง
Name[tr]=Duvar Kağıdı
Name[uk]=WallPaper
Name[x-test]=xxWallPaperxx
Name[zh_CN]=壁纸
Name[zh_TW]=桌布
Comment=A tool to set image as background on your desktop
Comment[ast]=Una ferramienta pa poner una imaxe como fondu de pantalla nel escritoriu
Comment[bg]=Инструмент за поставяне на изображения като тапет на екрана
Comment[bs]=Alat za postavljanje slike na vašu radnu površinu
Comment[ca]=Una eina per a definir una imatge com a fons de l'escriptori
Comment[ca@valencia]=Una eina per a definir una imatge com a fons de l'escriptori
Comment[cs]=Nástroj pro odeslání obrázku jako pozadí vaší plochy
Comment[da]=Et værktøj til at sætte et billede som baggrund på dit skrivebord
Comment[de]=Ein Werkzeug, um ein Bild als Hintergrundbild Ihrer Arbeitsfläche zu setzen.
Comment[el]=Εργαλείο ορισμού εικόνας ως φόντου της επιφάνειας εργασίας σας
Comment[en_GB]=A tool to set image as background on your desktop
Comment[es]=Una herramienta para configurar el fondo del escritorio
Comment[et]=Tööriist pildi määramiseks töölaua taustapildiks
Comment[eu]=Irudia mahaigaineko azteko plano gisa ezartzeko tresna
Comment[fi]=Taustakuvan vaihto
Comment[fr]=Outil pour mettre une image d'arrière plan sur le bureau
Comment[ga]=Uirlis a shocraíonn íomhá mar chúlbhrat do dheisce
Comment[gl]=Unha ferramenta para pór unha imaxe como fondo do escritorio
Comment[he]=כלי לקביעת התמונה כרקע של שולחן העבודה
Comment[hne]=फोटू ल आप मन के डेस्कटाप मं पिछोत अंगना फोटू रूप मं सेट करे के एक औजार
Comment[hu]=Egy eszköz kép beállításához az asztal háttérképeként
Comment[is]=Verkfæri til að setja mynd sem bakgrunn á skjáborðið þitt
Comment[it]=Uno strumento per impostare l'immagine come sfondo del desktop
Comment[ja]=画像をデスクトップの壁紙に設定するツール
Comment[km]=ឧបករណ៍​ត្រូវ​កំណត់​រូបភាព​ជា​ផ្ទៃ​ខាង​ក្រោយ​នៅ​លើ​ផ្ទៃតុ​របស់​អ្នក
Comment[lv]=Rīks attēla iestatīšanai par darbvirsmas ekrāntapeti
Comment[nb]=Et verktøy for å bruke et bilde som bakgrunn på skrivebordet
Comment[nds]=En Warktüüch, mit dat Du Biller as Achtergrund för Dien Schriefdisch bruken kannst.
Comment[nl]=Een hulpmiddel voor het instellen van een afbeelding als achtergrond van uw bureaublad
Comment[pa]=ਤੁਹਾਡੇ ਡੈਸਕਟਾਪ ਦੀ ਬੈਕਗਰਾਊਂਡ ਉੱਤੇ ਚਿੱਤਰ ਲਾਉਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do ustawiania obrazu jako tła twojego pulpitu
Comment[pt]=Uma ferramenta para configurar uma imagem como fundo do seu ecrã
Comment[pt_BR]=Uma ferramenta para definir imagem como plano de fundo de sua área de trabalho
Comment[ro]=O unealtă pentru definirea unei imagini ca fundal de ecran
Comment[ru]=Инструмент для установки изображения в качестве обоев рабочего стола
Comment[sk]=Nástroj na nastavenie obrázku ako pozadie pracovnej plochy
Comment[sl]=Orodje s katerim lahko nastavite sliko kot ozadje vašega namizja
Comment[sq]=Një mjet për të vendosur imazhin si sfond për desktopin tuaj
Comment[sv]=Ett verktyg för att använda bilder som skrivbordsunderlägg
Comment[th]=เครื่องมือในการตั้งภาพเป็นภาพพื้นหลังบนพื้นที่ทำงานของคุณ
Comment[tr]=Resimi masaüstü arkaplanı olarak belirlemek için bir araç
Comment[uk]=Інструмент для встановлення зображення тла стільниці
Comment[x-test]=xxA tool to set image as background on your desktopxx
Comment[zh_CN]=一个设定图像作为您桌面背景的工具
Comment[zh_TW]=將影像設定為您的桌面背景的工具
Type=Service
Icon=image-jpeg
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_wallpaper
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
